import pyfie
import matplotlib.pyplot as plt

# 利便のため PyFIE 関数が返すエラーコードに応じて例外を発生させる機能を有効化
pyfie.ctrl.enable_f_err_exception(True)

# 処理対象画像の読み込み
image = pyfie.imread("QR_image.png")

# QRコードオブジェクト生成
fQRCObj = pyfie.FHANDLE()
pyfie.fnFIE_qr_alloc_obj(fQRCObj)

# 検出モードの設定
pyfie.fnFIE_qr_set_effortlevel(fQRCObj, pyfie.F_QR_MAXIMUM_EFFORT)

# QRコード読み取り実行
pyfie.fnFIE_qr_execute(fQRCObj, image)

# QRコード読み取り情報とQRコード数の参照
piDecodedQRIndex = pyfie.INT.PTR()
iNumOfDecodedQRs = pyfie.INT()
pyfie.fnFIE_qr_query_decoded(fQRCObj, piDecodedQRIndex, iNumOfDecodedQRs)

# デコード成功数を表示
print("num decoded:", iNumOfDecodedQRs)

# デコード結果へアクセス
for i in range(iNumOfDecodedQRs):
    # デコードメッセージ取得
    message = pyfie.CHAR.PTR()
    pyfie.fnFIE_qr_query_message(fQRCObj, piDecodedQRIndex[i], message)

    # メッセージをPythonバイト列に変換
    message_byte_str = message.value_as_bytes
    # バイト文字列を通常の文字列にデコード。エンコーディングは ASCII
    message_str = message_byte_str.decode("ascii")

    # メッセージを表示
    print("message: {}".format(message_str))

# 画像オブジェクトのプロット
image.imshow()
# 結果をプロット
pyfie.mpltools.plot_qrcode_results(fQRCObj)
# 結果をプロットした画像の保存
plt.savefig("qr_result.png")
# 結果をプロットした画像の表示
pyfie.plot_show()
